@@ -121,6 +121,7 @@ class GemBox:
             if mail.Subject == None:
                 result.write("#\n")
             result.write(mail.GemText.string())
+        return result.getvalue()
             
 
     def string_B_old(self): # Deprecated
@@ -149,7 +150,7 @@ def parseGemBox(identifier, gembox_text = ""):
     currentGemMail = GemMail(None)
     for index, line in enumerate(lines):
         if line.startswith("["): # Start of new message data
-            if not inGboxMetadata:
+            if not inGboxMetadata and currentGemMail.ID != None:
                 # End of message body, append message to GemBox
                 currentGemMail = currentGemMail.setGemtextBody('\n'.join(lines[bodyStart:index]))
                 result.appendGemMail(currentGemMail)
@@ -223,6 +224,7 @@ def parseGemBox(identifier, gembox_text = ""):
                     if tagValueParts[1] == "true" or tagValueParts == "True" or tagValueParts == "TRUE":
                         value = True
                     currentGemMail.setTag(tagName, last_modification_date_timestamp, value)
+    return result
 
 
 def parseGemBox_B_old(identifier, gembox_text = ""): # Deprecated
